@@ -586,6 +586,10 @@ void dispatch::receive_cmd(const command& cmd)
         _parameters.set_audio_device(s11n::load<int>(p));
         notify_all(notification::audio_device);
         break;
+    case command::set_quality:
+        _parameters.set_quality(s11n::load<int>(p));
+        notify_all(notification::quality);
+        break;
     case command::set_stereo_mode:
         _parameters.set_stereo_mode(static_cast<parameters::stereo_mode_t>(s11n::load<int>(p)));
         notify_all(notification::stereo_mode);
@@ -795,7 +799,7 @@ void dispatch::receive_cmd(const command& cmd)
         notify_all(notification::crop_aspect_ratio);
         break;
     case command::adjust_parallax:
-        _parameters.set_parallax(clamp(_parameters.contrast() + s11n::load<float>(p), -1.0f, +1.0f));
+        _parameters.set_parallax(clamp(_parameters.parallax() + s11n::load<float>(p), -1.0f, +1.0f));
         notify_all(notification::parallax);
         break;
     case command::set_parallax:
@@ -811,7 +815,7 @@ void dispatch::receive_cmd(const command& cmd)
         notify_all(notification::ghostbust);
         break;
     case command::adjust_subtitle_parallax:
-        _parameters.set_subtitle_parallax(clamp(_parameters.contrast() + s11n::load<float>(p), -1.0f, +1.0f));
+        _parameters.set_subtitle_parallax(clamp(_parameters.subtitle_parallax() + s11n::load<float>(p), -1.0f, +1.0f));
         notify_all(notification::subtitle_parallax);
         break;
     case command::set_subtitle_parallax:
@@ -1060,6 +1064,9 @@ bool dispatch::parse_command(const std::string& s, command* c)
     } else if (tokens.size() == 2 && tokens[0] == "set-audio-device"
             && str::to(tokens[1], &p.i)) {
         *c = command(command::set_audio_device, p.i);
+    } else if (tokens.size() == 2 && tokens[0] == "set-quality"
+            && str::to(tokens[1], &p.i)) {
+        *c = command(command::set_quality, p.i);
     } else if (tokens.size() == 2 && tokens[0] == "set-stereo-mode"
             && parameters::parse_stereo_mode(tokens[1], &p_stereo_mode)) {
         *c = command(command::set_stereo_mode, static_cast<int>(p_stereo_mode));
